==> komga_api_client-0.41.1.tar.gz: lib/api.dart <==
library komga_api_client.api;

import 'package:dio/dio.dart';
import 'package:built_value/serializer.dart';
import 'package:komga_api_client/serializers.dart';
import 'package:komga_api_client/auth/api_key_auth.dart';
import 'package:komga_api_client/auth/basic_auth.dart';
import 'package:komga_api_client/auth/oauth.dart';
import 'package:komga_api_client/api/book_controller_api.dart';
import 'package:komga_api_client/api/claim_controller_api.dart';
import 'package:komga_api_client/api/file_system_controller_api.dart';
import 'package:komga_api_client/api/library_controller_api.dart';
import 'package:komga_api_client/api/opds_controller_api.dart';
import 'package:komga_api_client/api/referential_controller_api.dart';
import 'package:komga_api_client/api/series_collection_controller_api.dart';
import 'package:komga_api_client/api/series_controller_api.dart';
import 'package:komga_api_client/api/user_controller_api.dart';


final _defaultInterceptors = [OAuthInterceptor(), BasicAuthInterceptor(), ApiKeyAuthInterceptor()];

class KomgaApiClient {

    Dio dio;
    Serializers serializers;
    String basePath = "http://localhost:8080";

    KomgaApiClient({this.dio, Serializers serializers, String basePathOverride, List<Interceptor> interceptors}) {
        if (dio == null) {
            BaseOptions options = new BaseOptions(
                baseUrl: basePathOverride ?? basePath,
                connectTimeout: 5000,
                receiveTimeout: 3000,
            );
            this.dio = new Dio(options);
        }

        if (interceptors == null) {
            this.dio.interceptors.addAll(_defaultInterceptors);
        } else {
            this.dio.interceptors.addAll(interceptors);
        }

        this.serializers = serializers ?? standardSerializers;
    }

    void setOAuthToken(String name, String token) {
        (this.dio.interceptors.firstWhere((element) => element is OAuthInterceptor, orElse: null) as OAuthInterceptor)?.tokens[name] = token;
    }

    void setBasicAuth(String name, String username, String password) {
        (this.dio.interceptors.firstWhere((element) => element is BasicAuthInterceptor, orElse: null) as BasicAuthInterceptor)?.authInfo[name] = BasicAuthInfo(username, password);
    }

    void setApiKey(String name, String apiKey) {
        (this.dio.interceptors.firstWhere((element) => element is ApiKeyAuthInterceptor, orElse: null) as ApiKeyAuthInterceptor)?.apiKeys[name] = apiKey;
    }


    /**
    * Get BookControllerApi instance, base route and serializer can be overridden by a given but be careful,
    * by doing that all interceptors will not be executed
    */
    BookControllerApi getBookControllerApi() {
    return BookControllerApi(dio, serializers);
    }


    /**
    * Get ClaimControllerApi instance, base route and serializer can be overridden by a given but be careful,
    * by doing that all interceptors will not be executed
    */
    ClaimControllerApi getClaimControllerApi() {
    return ClaimControllerApi(dio, serializers);
    }


    /**
    * Get FileSystemControllerApi instance, base route and serializer can be overridden by a given but be careful,
    * by doing that all interceptors will not be executed
    */
    FileSystemControllerApi getFileSystemControllerApi() {
    return FileSystemControllerApi(dio, serializers);
    }


    /**
    * Get LibraryControllerApi instance, base route and serializer can be overridden by a given but be careful,
    * by doing that all interceptors will not be executed
    */
    LibraryControllerApi getLibraryControllerApi() {
    return LibraryControllerApi(dio, serializers);
    }


    /**
    * Get OpdsControllerApi instance, base route and serializer can be overridden by a given but be careful,
    * by doing that all interceptors will not be executed
    */
    OpdsControllerApi getOpdsControllerApi() {
    return OpdsControllerApi(dio, serializers);
    }


    /**
    * Get ReferentialControllerApi instance, base route and serializer can be overridden by a given but be careful,
    * by doing that all interceptors will not be executed
    */
    ReferentialControllerApi getReferentialControllerApi() {
    return ReferentialControllerApi(dio, serializers);
    }


    /**
    * Get SeriesCollectionControllerApi instance, base route and serializer can be overridden by a given but be careful,
    * by doing that all interceptors will not be executed
    */
    SeriesCollectionControllerApi getSeriesCollectionControllerApi() {
    return SeriesCollectionControllerApi(dio, serializers);
    }


    /**
    * Get SeriesControllerApi instance, base route and serializer can be overridden by a given but be careful,
    * by doing that all interceptors will not be executed
    */
    SeriesControllerApi getSeriesControllerApi() {
    return SeriesControllerApi(dio, serializers);
    }


    /**
    * Get UserControllerApi instance, base route and serializer can be overridden by a given but be careful,
    * by doing that all interceptors will not be executed
    */
    UserControllerApi getUserControllerApi() {
    return UserControllerApi(dio, serializers);
    }


}

==> komga_api_client-37.0.0.tar.gz: lib/api.dart <==
library komga_api_client.api;

import 'package:dio/dio.dart';
import 'package:built_value/serializer.dart';
import 'package:komga_api_client/serializers.dart';
import 'package:komga_api_client/auth/api_key_auth.dart';
import 'package:komga_api_client/auth/basic_auth.dart';
import 'package:komga_api_client/auth/oauth.dart';
import 'package:komga_api_client/api/book_controller_api.dart';
import 'package:komga_api_client/api/claim_controller_api.dart';
import 'package:komga_api_client/api/file_system_controller_api.dart';
import 'package:komga_api_client/api/library_controller_api.dart';
import 'package:komga_api_client/api/referential_controller_api.dart';
import 'package:komga_api_client/api/series_controller_api.dart';
import 'package:komga_api_client/api/user_controller_api.dart';


final _defaultInterceptors = [OAuthInterceptor(), BasicAuthInterceptor(), ApiKeyAuthInterceptor()];

class KomgaApiClient {

    Dio dio;
    Serializers serializers;
    String basePath = "https://demo.komga.org";

    KomgaApiClient({this.dio, Serializers serializers, String basePathOverride, List<Interceptor> interceptors}) {
        if (dio == null) {
            BaseOptions options = new BaseOptions(
                baseUrl: basePathOverride ?? basePath,
                connectTimeout: 5000,
                receiveTimeout: 3000,
            );
            this.dio = new Dio(options);
        }

        if (interceptors == null) {
            this.dio.interceptors.addAll(_defaultInterceptors);
        } else {
            this.dio.interceptors.addAll(interceptors);
        }

        this.serializers = serializers ?? standardSerializers;
    }

    void setOAuthToken(String name, String token) {
        (this.dio.interceptors.firstWhere((element) => element is OAuthInterceptor, orElse: null) as OAuthInterceptor)?.tokens[name] = token;
    }

    void setBasicAuth(String name, String username, String password) {
        (this.dio.interceptors.firstWhere((element) => element is BasicAuthInterceptor, orElse: null) as BasicAuthInterceptor)?.authInfo[name] = BasicAuthInfo(username, password);
    }

    void setApiKey(String name, String apiKey) {
        (this.dio.interceptors.firstWhere((element) => element is ApiKeyAuthInterceptor, orElse: null) as ApiKeyAuthInterceptor)?.apiKeys[name] = apiKey;
    }


    /**
    * Get BookControllerApi instance, base route and serializer can be overridden by a given but be careful,
    * by doing that all interceptors will not be executed
    */
    BookControllerApi getBookControllerApi() {
    return BookControllerApi(dio, serializers);
    }


    /**
    * Get ClaimControllerApi instance, base route and serializer can be overridden by a given but be careful,
    * by doing that all interceptors will not be executed
    */
    ClaimControllerApi getClaimControllerApi() {
    return ClaimControllerApi(dio, serializers);
    }


    /**
    * Get FileSystemControllerApi instance, base route and serializer can be overridden by a given but be careful,
    * by doing that all interceptors will not be executed
    */
    FileSystemControllerApi getFileSystemControllerApi() {
    return FileSystemControllerApi(dio, serializers);
    }


    /**
    * Get LibraryControllerApi instance, base route and serializer can be overridden by a given but be careful,
    * by doing that all interceptors will not be executed
    */
    LibraryControllerApi getLibraryControllerApi() {
    return LibraryControllerApi(dio, serializers);
    }


    /**
    * Get ReferentialControllerApi instance, base route and serializer can be overridden by a given but be careful,
    * by doing that all interceptors will not be executed
    */
    ReferentialControllerApi getReferentialControllerApi() {
    return ReferentialControllerApi(dio, serializers);
    }


    /**
    * Get SeriesControllerApi instance, base route and serializer can be overridden by a given but be careful,
    * by doing that all interceptors will not be executed
    */
    SeriesControllerApi getSeriesControllerApi() {
    return SeriesControllerApi(dio, serializers);
    }


    /**
    * Get UserControllerApi instance, base route and serializer can be overridden by a given but be careful,
    * by doing that all interceptors will not be executed
    */
    UserControllerApi getUserControllerApi() {
    return UserControllerApi(dio, serializers);
    }


}
